#
# spec file for package php-pear-Net_SMTP
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define pear_name  Net_SMTP

Name:           php-pear-Net_SMTP
Version:        1.12.1
Release:        bp160.1.6
Summary:        An implementation of the SMTP protocol
License:        BSD-2-Clause
Group:          Development/Libraries/Other
URL:            https://pear.php.net/package/%{pear_name}
Source:         https://pear.php.net/get/%{pear_name}-%{version}.tgz
BuildRequires:  php-devel
BuildRequires:  php-pear
Requires:       php-pear
Requires:       php-pear(Net_Socket) >= 1.0.7
Recommends:     php-pear(Auth_SASL) >= 1.0.5
Provides:       php-pear(%{pear_name}) = %{version}
# PHP5 last used in openSUSE:Leap_42.3
Provides:       php5-pear-%{pear_name} = %{version}
Obsoletes:      php5-pear-%{pear_name} < %{version}
Provides:       php7-pear-%{pear_name} = %{version}
Obsoletes:      php7-pear-%{pear_name} < %{version}
BuildArch:      noarch

%description
Provides an implementation of the SMTP protocol using PEAR's Net_Socket class.

%prep
%setup -q -n %{pear_name}-%{version}
# move package.xml when needed
[ -f ../package.xml ] &&  mv ../package.xml . || :

%build

%install
%{__pear} install --nodeps --offline --packagingroot %{buildroot} package.xml
install -D -m 0644 package.xml %{buildroot}%{php_pearxmldir}/%{pear_name}.xml

%{php_pear_gen_filelist}

%post
if [ "$1" = "1" ]; then
  # on "rpm -ivh"
  %{__pear} install --nodeps --soft --force --register-only %{php_pearxmldir}/%{pear_name}.xml || :
fi
if [ "$1" = "2" ]; then
  # on "rpm -Uvh"
  %{__pear} upgrade --offline --register-only %{php_pearxmldir}/%{pear_name}.xml || :
fi

%postun
if [ "$1" = "0" ]; then
  # on "rpm -e"
  %{__pear} uninstall --nodeps --ignore-errors --register-only pear.php.net/%{pear_name} || :
fi

%files -f %{name}.files
%docdir %{pear_docdir}
%exclude %{pear_metadir}/.??*
%exclude %{pear_testdir}

%changelog
* Sun May 26 2024 Arjen de Korte <suse+build@de-korte.org>
- New upstream release 1.12.1
  * Bug: Don't enable GSSAPI method if principal is not set (#81) (#82)
- New upstream release 1.12.0
  * Feature: add support of OAUTHBEARER (#79)
* Wed Nov  1 2023 Arjen de Korte <suse+build@de-korte.org>
- New upstream release 1.11.1
  * BugFix: Triggering deprecation warnings in error-log causes system
    failures because of changing the behavior in error reporting (#76)
- New upstream release 1.11.0
  * Feature: Add SCRAM-SHA-1, SCRAM-SHA-224, SCRAM-SHA-256, SCRAM-SHA-384
    and SCRAM-SHA-512 support (#76)
  * Task: Mark authentication methods CRAM-MD5, DIGEST-MD5 and LOGIN as
    DEPRECATED with deprecation warnings in the error-log (#76)
  * BugFix: SMTP: STARTTLS failed (code: 220, response: 2.0.0 Ready to
    start TLS) (#74)
  * BugFix: Issue with non-blocking streams on establishing STARTTLS
    encryption (#74)
  * BugFix: Implement TLS1.3 on STARTTLS encryption (#74)
  * BugFix: using implode() instead of join() (#74)
* Thu Sep 29 2022 Arjen de Korte <suse+build@de-korte.org>
- New upstream release 1.10.1
  * (authXOAuth2) longer tokens violate maximum SMTP command line length
  * (disconnect) socket will not disconnect on erroneous response upon
    QUIT message
  * Fix PHP 8.2 deprecation warnings on undefined properties
* Sat Jun  5 2021 Arjen de Korte <suse+build@de-korte.org>
- New upstream release 1.10.0
  * Add the starttls() method
* Tue Aug 18 2020 Arjen de Korte <suse+build@de-korte.org>
- New upstream release 1.9.2
  * Repackage documentation
* Sun Jun  7 2020 Arjen de Korte <suse+build@de-korte.org>
- New upstream release 1.9.1
  * Added .gitattributes for nicer packaging
* Thu Dec  5 2019 Arjen de Korte <suse+build@de-korte.org>
- make package PHP version independent
- new upstream release 1.9.0
  * Added support for the XOAUTH2 authentication method
- use correct macro to reference metadata (boo#1158112)
- clean-up spec, use https for downloading
* Mon Jan  7 2019 ecsos@opensuse.org
- New upstream release 1.8.1
  * Don't disconnect when message size exceeds server limit
  * Added GSSAPI support via the PECL krb5 module
  * Updated composer requirements to use stable dependencies
- Run spec-cleaner
* Sun Sep 10 2017 jweberhofer@weberhofer.at
- Cleaned up spec
* Fri Aug 18 2017 ecsos@opensuse.org
- New upstream release 1.8.0
  * Set minimum PEAR version to 1.10.1
  * Change license to BSD-2 Clause
- changes from 1.7.3
  * Fix MIME boundary size calculation (#34)
  * Workaround E_DEPRECATED warning on Auth_SASL::factory() call (#29)
- changes from 1.7.2
  * Fix size calculation when headers are provided (#27)
- renamed packer to php7-pear-Net_SMTP
* Tue Sep 15 2015 aj@ajaissle.de
- New upstream release 1.7.1
  * Fix a syntax error in the quotedata() test.
  * Fix an undefined value resulting from a bad merge. (#23)
  * Add TLSv1.1 and TLSv1.2 support for STARTTLS connections. (#22)
- Changes 1.7.0:
  * This version drops PHP 4 support in favor of more modern PHP language constructs.
* Sun Nov 24 2013 aj@ajaissle.de
- Changed BuildRequires to work on openSUSE 11.4
* Fri Nov  8 2013 aj@ajaissle.de
- New upstream release 1.6.2
  * Fix EHLO response handling for HELO-only servers.
* Tue Nov 27 2012 Ralf Lang <lang@b1-systems.de>
- version 1.6.1
- Fixing the detection of SASL-based AUTH methods. (pear Bug #18594)
- Adding a new command() method for sending arbitrary SMTP commands.
- More kinds of socket write() failures are now detected.
- Improved PEAR_Error internal handling. (Bug 18469)
- External authentication methods are now supported via setAuthMethod().
- Resource-based data streams are no longer terminated prematurely. (pear Bug #18563)
- Avoid appending an extra space in mailFrom() when $params is empty. (pear Bug #17989)
- Differentiating between a connection timeout and general socket I/O timeouts. (pear Request #18197)
* Thu Jan 20 2011 chris@computersalat.de
- change to php_pear_gen_filelist macro
* Wed Jan 19 2011 chris@computersalat.de
- pkg rename php5-pear-Net_SMTP
- merge with php-pear-net_smtp, php5-pear-net_smtp
- dr for php-pear-net_smtp, php5-pear-net_smtp
- update to 1.4.4
  * Corrected a problem with SMTP servers that don't support the SIZE
    feature. (Bug 17942)
- 1.4.3
  - Reduce peak memory usage when sending large files. (Request 17887)
  - Adding support for proxy authentication. (Request 17358)
- for more info please see ChangeLog
    http://pear.php.net/package/Net_SMTP/download/All
- added php-macros
- cleanup spec
* Tue Nov 10 2009 chris@computersalat.de
- new version 1.3.3
  * (Request #16066)
    Added getGreeting(), for retrieving the server's greeting string.
  * (Bug #16254)
    We no longer attempt a TLS connection if we're already using a
    secure socket.
  * (Request #16420)
    You can now specify a debug output handler via setDebug().
- cleanup spec
  * removed ^#---
  * removed {rel}
* Sat May 30 2009 chris@computersalat.de
- fixed post script
* Thu May 21 2009 chris@computersalat.de
- new version 1.3.2
- beautify spec
  o new spec header
  o package rename due to package convention
  o removed php4 stuff, deps
  o added Provides and Obsoletes for old package names.
    This should not break deps
- added stuff to automatically create correct filelist
  o tested against Factory (1120)
  o opensuse >= 1100 complains about
    "directory not owned by package"
- some rpmlint fixes
* Tue Dec 23 2008 rbos@opensuse.org
- Added php5-pear-net_socket as dependency, this rpms provides
  the directory %%%%{peardir}/Net
* Wed Dec 17 2008 rbos@opensuse.org
- Updated to version 1.3.1
- Prevent rpmlint error "directories not owned by a package"
- use (again) --installroot instead of --packagingroot.  The latter results
  in build failures
* Thu Dec  7 2006 suse-tux@gmx.de
- use --packagingroot instead of --installroot
* Sun Oct 29 2006 suse-tux@gmx.de
- update to version 1.2.8
- minor spec file changes
* Sat Jun 10 2006 suse-tux@gmx.de
- made spec file portable for other suse-versions
- adapt name tag to suse's php-pear-naming-style
- added php.ini otherwise it doesn't build on 10.1 (too less memory)   (thanks darix)
* Mon Apr 17 2006 suse-tux@gmx.de
- rebuild on 10.1
* Mon Jan 23 2006 suse-tux@gmx.de
- initial build
